==> txrc-0.1.0-1.tar.gz: txrc-0.1.0/docs/release_checklist.md <==
<!--- -*- encoding: utf-8; grammar-ext: md; mode: markdown -*-
  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  >>>>>>>>>>>>>>>> IMPORTANT: READ THIS BEFORE EDITING! <<<<<<<<<<<<<<<<
  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  Please keep each sentence on its own unwrapped line.
  It looks like crap in a text editor, but it has no effect on rendering, and it allows much more useful diffs.
  Thank you! -->

Copyright © 2015 [Matt Bogosian](mailto:mtb19@columbia.edu?Subject=txrc) ([**@posita**](https://github.com/posita)).

Please see the accompanying [`LICENSE`](LICENSE) (or [`LICENSE.txt`](LICENSE)) file for rights and restrictions governing use of this software.
All rights not expressly waived or licensed are reserved.
If such a file did not accompany this software, then please contact the author before viewing or using this software in any capacity.

- [ ] `git checkout -b X.Y.Z-release`

- [ ] Set version in [`txrc/version.py`](txrc/version.py)

```diff
diff --git a/txrc/version.py b/txrc/version.py
index 0123456..fedcba9 100644
--- a/txrc/version.py
+++ b/txrc/version.py
@@ -25,5 +25,5 @@ from __future__ import (

 __all__ = ()

-__version__ = 'master'
-__release__ = 'master'
+__version__ = 'X.Y.Z'
+__release__ = 'vX.Y.Z'
```

- [ ] Set version in [`README.rst`](README.rst) (`master` → `vX.Y.Z`, except for [`https://pypi.python.org/pypi/txrc/X.Y.Z`](https://pypi.python.org/pypi/txrc/X.Y.Z))

- [ ] `git commit -a -m 'Update version and release vX.Y.Z.'`

- [ ] `git tag -s -f -m 'Release vX.Y.Z.' vX.Y.Z`

- [ ] `./setup.py sdist upload`

- [ ] Upload `txrc.egg-info/PKG-INFO` to [`https://pypi.python.org/pypi?:action=submit_form&name=txrc&version=X.Y.Z`](https://pypi.python.org/pypi?:action=submit_form&name=txrc&version=X.Y.Z) (work-around)

- [ ] `git checkout master`

- [ ] `git branch -d X.Y.Z-release`

==> txrc-0.2.0-3.tar.gz: txrc-0.2.0/docs/release_checklist.md <==
<!--- -*- encoding: utf-8; grammar-ext: md; mode: markdown -*-
  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  >>>>>>>>>>>>>>>> IMPORTANT: READ THIS BEFORE EDITING! <<<<<<<<<<<<<<<<
  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
  Please keep each sentence on its own unwrapped line.
  It looks like crap in a text editor, but it has no effect on rendering, and it allows much more useful diffs.
  Thank you! -->

Copyright © 2015 [Matt Bogosian](mailto:mtb19@columbia.edu?Subject=txrc) ([**@posita**](https://github.com/posita)).

Please see the accompanying [`LICENSE`](LICENSE) (or [`LICENSE.txt`](LICENSE)) file for rights and restrictions governing use of this software.
All rights not expressly waived or licensed are reserved.
If such a file did not accompany this software, then please contact the author before viewing or using this software in any capacity.

- [ ] `git checkout -b X.Y.Z-release`

- [ ] Set version in [`txrc/version.py`](txrc/version.py)

```diff
diff --git a/txrc/version.py b/txrc/version.py
index 0123456..fedcba9 100644
--- a/txrc/version.py
+++ b/txrc/version.py
@@ -25,5 +25,5 @@ from __future__ import (

 __all__ = ()

-__version__ = 'master'
-__release__ = 'master'
+__version__ = 'X.Y.Z'
+__release__ = 'vX.Y.Z'
```

- [ ] Set version in [`README.rst`](README.rst) (`master` → `vX.Y.Z`; [`https://pypi.python.org/pypi/txrc`](https://pypi.python.org/pypi/txrc) → [`https://pypi.python.org/pypi/txrc/X.Y.Z`](https://pypi.python.org/pypi/txrc/X.Y.Z);  [`https://img.shields.io/pypi/.../txrc.svg`](https://img.shields.io/pypi/.../txrc.svg) →  [`https://img.shields.io/pypi/.../txrc/X.Y.Z.svg`](https://img.shields.io/pypi/.../txrc/X.Y.Z.svg))

- [ ] `git commit --all --message 'Update version and release vX.Y.Z.'`

- [ ] `git tag --sign --force --message 'Release vX.Y.Z.' vX.Y.Z`

- [ ] `git push --tags`

- [ ] `./setup.py sdist upload`

- [ ] Upload `txrc.egg-info/PKG-INFO` to [`https://pypi.python.org/pypi?:action=submit_form&name=txrc&version=X.Y.Z`](https://pypi.python.org/pypi?:action=submit_form&name=txrc&version=X.Y.Z) (work-around)

- [ ] `git checkout master`

- [ ] `git branch --delete X.Y.Z-release`
